@@ -21,7 +21,7 @@ except ImportError:
 from tempfile import NamedTemporaryFile, mkdtemp
 from osc.fetch import *
 from osc.core import get_buildinfo, store_read_apiurl, store_read_project, store_read_package, meta_exists, quote_plus, get_buildconfig, is_package_dir, dgst
-from osc.core import get_binarylist, get_binary_file, run_external, raw_input
+from osc.core import get_binarylist, get_binary_file, run_external, return_external, raw_input
 from osc.util import rpmquery, debquery, archquery
 import osc.conf
 from . import oscerr
@@ -90,7 +90,7 @@ if hostarch == 'parisc':
 class Buildinfo:
     """represent the contents of a buildinfo file"""
 
-    def __init__(self, filename, apiurl, buildtype = 'spec', localpkgs = []):
+    def __init__(self, filename, apiurl, buildtype = 'spec', localpkgs = [], binarytype = 'rpm'):
         try:
             tree = ET.parse(filename)
         except:
@@ -117,12 +117,13 @@ class Buildinfo:
             raise URLError('invalid protocol for the apiurl: \'%s\'' % apiurl)
 
         self.buildtype = buildtype
+        self.binarytype = binarytype
         self.apiurl = apiurl
 
         # are we building .rpm or .deb?
         # XXX: shouldn't we deliver the type via the buildinfo?
         self.pacsuffix = 'rpm'
-        if self.buildtype == 'dsc' or self.buildtype == 'collax':
+        if self.buildtype == 'dsc' or self.buildtype == 'collax' or self.binarytype == 'deb':
             self.pacsuffix = 'deb'
         if self.buildtype == 'arch':
             self.pacsuffix = 'arch'
@@ -349,6 +350,11 @@ def get_built_files(pacdir, buildtype):
                                     '-type', 'f'],
                                    stdout=subprocess.PIPE).stdout.read().strip()
         s_built = ''
+    elif buildtype == 'fissile':
+        b_built = subprocess.Popen(['find', os.path.join(pacdir, 'FISSILE'),
+                                    '-type', 'f'],
+                                   stdout=subprocess.PIPE).stdout.read().strip()
+        s_built = ''
     elif buildtype == 'dsc' or buildtype == 'collax':
         b_built = subprocess.Popen(['find', os.path.join(pacdir, 'DEBS'),
                                     '-name', '*.deb'],
@@ -485,7 +491,7 @@ def check_trusted_projects(apiurl, projects):
             print("Note that malicious packages can compromise the build result or even your system.")
             r = raw_input(trustprompt % { 'project': prj })
             if r == '1':
-                print("adding '%s' to ~/.oscrc: ['%s']['trusted_prj']" % (prj, apiurl))
+                print("adding '%s' to oscrc: ['%s']['trusted_prj']" % (prj, apiurl))
                 trusted.append(prj)
             elif r != '2':
                 print("Well, good good bye then :-)")
@@ -520,7 +526,9 @@ def main(apiurl, opts, argv):
         build_type = 'snapcraft'
     if os.path.basename(build_descr) == 'Dockerfile':
         build_type = 'docker'
-    if build_type not in ['spec', 'dsc', 'kiwi', 'arch', 'collax', 'livebuild', 'snapcraft', 'appimage', 'docker']:
+    if os.path.basename(build_descr) == 'fissile.yml':
+        build_type = 'fissile'
+    if build_type not in ['spec', 'dsc', 'kiwi', 'arch', 'collax', 'livebuild', 'snapcraft', 'appimage', 'docker', 'fissile']:
         raise oscerr.WrongArgs(
                 'Unknown build type: \'%s\'. Build description should end in .spec, .dsc, .kiwi, or .livebuild. Or being named PKGBUILD, build.collax, appimage.yml, snapcraft.yaml or Dockerfile' \
                         % build_type)
@@ -804,7 +812,15 @@ def main(apiurl, opts, argv):
         else:
             raise
 
-    bi = Buildinfo(bi_filename, apiurl, build_type, list(prefer_pkgs.keys()))
+    # Set default binary type if cannot be detected
+    binary_type = 'rpm'
+    if os.path.exists('/usr/lib/build/queryconfig'):
+        binary_type = return_external('/usr/lib/build/queryconfig', '--dist', bc_filename, 'binarytype').decode('utf-8').strip()
+    # If binary type is set to a useless value, reset to 'rpm'
+    if binary_type == 'UNDEFINED':
+        binary_type = 'rpm'
+
+    bi = Buildinfo(bi_filename, apiurl, build_type, list(prefer_pkgs.keys()), binary_type)
 
     if bi.debuginfo and not (opts.disable_debuginfo or '--debug' in buildargs):
         buildargs.append('--debug')
@@ -961,8 +977,8 @@ def main(apiurl, opts, argv):
         if old_pkg_dir != None:
             buildargs.append('--oldpackages=%s' % old_pkg_dir)
 
-    # Make packages from buildinfo available as repos for kiwi/docker
-    if build_type == 'kiwi' or build_type == 'docker':
+    # Make packages from buildinfo available as repos for kiwi/docker/fissile
+    if build_type == 'kiwi' or build_type == 'docker' or build_type == 'fissile':
         if os.path.exists('repos'):
             shutil.rmtree('repos')
         if os.path.exists('containers'):
@@ -1105,7 +1121,7 @@ def main(apiurl, opts, argv):
 
     print('Writing build configuration')
 
-    if build_type == 'kiwi' or build_type == 'docker':
+    if build_type == 'kiwi' or build_type == 'docker' or build_type == 'fissile':
         rpmlist = [ '%s %s\n' % (i.name, i.fullfilename) for i in bi.deps if not i.noinstall ]
     else:
         rpmlist = [ '%s %s\n' % (i.name, i.fullfilename) for i in bi.deps ]
@@ -1121,10 +1137,11 @@ def main(apiurl, opts, argv):
     rpmlist.append('preinstall: ' + ' '.join(bi.preinstall_list) + '\n')
     rpmlist.append('vminstall: ' + ' '.join(bi.vminstall_list) + '\n')
     rpmlist.append('runscripts: ' + ' '.join(bi.runscripts_list) + '\n')
-    if build_type != 'kiwi' and build_type != 'docker' and bi.noinstall_list:
-        rpmlist.append('noinstall: ' + ' '.join(bi.noinstall_list) + '\n')
-    if build_type != 'kiwi' and build_type != 'docker' and bi.installonly_list:
-        rpmlist.append('installonly: ' + ' '.join(bi.installonly_list) + '\n')
+    if build_type != 'kiwi' and build_type != 'docker' and build_type != 'fissile':
+        if bi.noinstall_list:
+            rpmlist.append('noinstall: ' + ' '.join(bi.noinstall_list) + '\n')
+        if bi.installonly_list:
+            rpmlist.append('installonly: ' + ' '.join(bi.installonly_list) + '\n')
 
     rpmlist_file = NamedTemporaryFile(prefix='rpmlist.')
     rpmlist_filename = rpmlist_file.name
